@@ -995,6 +995,18 @@ table = [
         "source": "BD",
         "video_resolution": "720p"
     },
+    {
+        "anime_season": 1,
+        "anime_season_prefix": "S",
+        "anime_title": "Natsu no Arashi!",
+        "episode_number": 1,
+        "episode_prefix": "E",
+        "episode_title": "Playback Part 2",
+        "file_checksum": "BD00F464",
+        "file_extension": "mkv",
+        "file_name": "[EMBER] Natsu no Arashi! - S01E01-Playback Part 2 [BD00F464].mkv",
+        "release_group": "EMBER"
+    },
     {
         "anime_title": "One Piece",
         "episode_number": 1000,
